==> OctoBot-0.2.4b2-py2.py3-none-any.whl: OctoBot-0.2.4b2.data/data/interfaces/cst.js <==
/*
 * Drakkar-Software OctoBot
 * Copyright (c) Drakkar-Software, All rights reserved.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 3.0 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library.
 */

// dom data attributes and classes
const config_key_attr = "config-key";
const config_value_attr = "config-value";
const current_value_attr = "current-value";
const startup_value_attr = "startup-config-value";
const update_url_attr = "update-url";
const config_type_attr = "config-type";
const config_data_type_attr = "data-type";
const config_root_class = "config-root";
const config_container_class = "config-container";
const config_element_class = "config-element";
const no_activation_click_attr = "no-activation-click";

// dom display classes
const success_badge = "badge-success";
const warning_badge = "badge-warning";
const secondary_badge = "badge-secondary";
const primary_badge = "badge-primary";
const modified_class = "warning-color";
const selected_item_class = "primary-color";
const disabled_item_class = "stylish-color";
const hidden_class = "d-none";
const disabled_class = "disabled-item";

const card_class_modified = "card-modified";
const deck_container_modified_class = "deck-container-modified";
const deck_container_class = "deck-container";
const config_card_class = "config-card";
const added_class = "new_element";

const light_list_item = "list-group-item-light";
const success_list_item = "list-group-item-success";

const activation_pending = "Activation pending restart";
const deactivation_pending = "Deactivation pending restart";
const unsaved_setting = "Unsaved setting";
const activated = "Activated";
const deactivated = "Deactivated";

const config_default_value = "Bitcoin";
const config_default_symbol = "btc";

const evaluator_config_type = "evaluator_config";
const trading_config_type = "trading_config";

==> OctoBot-0.3.2b0-py2.py3-none-any.whl: OctoBot-0.3.2b0.data/data/interfaces/cst.js <==
/*
 * Drakkar-Software OctoBot
 * Copyright (c) Drakkar-Software, All rights reserved.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 3.0 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library.
 */

// dom data attributes and classes
const config_key_attr = "config-key";
const config_value_attr = "config-value";
const current_value_attr = "current-value";
const startup_value_attr = "startup-config-value";
const update_url_attr = "update-url";
const config_type_attr = "config-type";
const config_data_type_attr = "data-type";
const config_root_class = "config-root";
const config_container_class = "config-container";
const config_element_class = "config-element";
const no_activation_click_attr = "no-activation-click";

// dom display classes
const success_badge = "badge-success";
const warning_badge = "badge-warning";
const secondary_badge = "badge-secondary";
const primary_badge = "badge-primary";
const modified_class = "warning-color";
const selected_item_class = "primary-color";
const disabled_item_class = "d-none";
const hidden_class = "d-none";
const disabled_class = "disabled-item";

const card_class_modified = "card-modified";
const deck_container_modified_class = "deck-container-modified";
const deck_container_class = "deck-container";
const config_card_class = "config-card";
const added_class = "new_element";

const light_list_item = "list-group-item-light";
const success_list_item = "list-group-item-success";

const activation_pending = "Activation pending restart";
const deactivation_pending = "Deactivation pending restart";
const unsaved_setting = "Unsaved setting";
const activated = "Activated";
const deactivated = "Deactivated";

const config_default_value = "Bitcoin";
const config_default_symbol = "btc";

const evaluator_config_type = "evaluator_config";
const evaluator_list_config_type = "evaluator_list_config";
const trading_config_type = "trading_config";

const max_attempts = 20;

const material_colors = ["#2962ff", "#00b8d4", "#00c853", "#aeea00", "#ffab00",
    "#dd2c00", "#d50000", "#6200ea"];

const material_dark_colors = ["#0039cb", "#0088a3", "#009624", "#79b700", "#c67c00",
    "#a30000", "#9b0000", "#0a00b6"];
